@@ -1,7 +1,10 @@
 import os
-from django.core.management.base import BaseCommand, CommandError
+
+from django.core.management.base import BaseCommand
 from django.conf import settings
-from _generate_view import generate_view
+
+from angular_scaffold.management.commands.helpers._generate_view import generate_view
+
 
 class Command(BaseCommand):
     args = '<view_name view_name ...>'
